@@ -18,7 +18,7 @@
 //
 //    You should have received a copy of the GNU General Public License
 //    along with this program; if not, write to the Free Software
-//    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+//    Foundation, Inc., 51 Franklin Steet, Fifth Floor, Cambridge, MA 02110-1301, USA.
 //
 //////////////////////////////////////////////////////////////////////////////
 
@@ -30,10 +30,12 @@
 #include <qptrlist.h>
 #include <qdatetime.h>
 
+#include "libkexif_export.h"
+
 class KExifIfd;
 class KExifDataPriv;
 
-class KExifData
+class LIBKEXIF_EXPORT KExifData
 {
 public:
 
