@@ -18,7 +18,7 @@
 //
 //    You should have received a copy of the GNU General Public License
 //    along with this program; if not, write to the Free Software
-//    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+//    Foundation, Inc., 51 Franklin Steet, Fifth Floor, Cambridge, MA 02110-1301, USA.
 //
 //////////////////////////////////////////////////////////////////////////////
 
@@ -37,6 +37,7 @@
 // KDE includes.
 
 #include <klocale.h>
+#include <kglobal.h>
 #include <kpopupmenu.h>
 #include <kapplication.h>
 #include <kurl.h>
@@ -55,12 +56,15 @@ KExifDialog::KExifDialog(QWidget *parent, const char *name)
      : KDialogBase( Plain, i18n("EXIF Information"), Help|Close,
                     Close, parent, name, true )
 {
+    // insert the catalogue for libkexif
+    KGlobal::locale()->insertCatalogue("libkexif");
+    
     // About data and help button.
    
     // All bugs must be reported to Digikam account in bko.
     KAboutData* about = new KAboutData("digikam",
                                        I18N_NOOP("KExif"), 
-                                       "0.2.1",  
+                                       "0.2.2",  
                                        I18N_NOOP("An Exif data viewer"),
                                        KAboutData::License_GPL,
                                        "(c) 2003-2004, Digikam team", 
@@ -112,7 +116,7 @@ KExifDialog::KExifDialog(QWidget *parent, const char *name)
     nameComboLay->addWidget(hline);
     
     QHBoxLayout* comboLay   = new QHBoxLayout(nameComboLay);
-    QLabel* modeComboLabel  = new QLabel(i18n("Select Level of detail:"), plainPage());
+    QLabel* modeComboLabel  = new QLabel(i18n("Select level of detail:"), plainPage());
     m_modeComboBox = new QComboBox(plainPage());
     comboLay->addWidget(modeComboLabel);
     comboLay->addWidget(m_modeComboBox);
