@@ -18,7 +18,7 @@
 //
 //    You should have received a copy of the GNU General Public License
 //    along with this program; if not, write to the Free Software
-//    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+//    Foundation, Inc., 51 Franklin Steet, Fifth Floor, Cambridge, MA 02110-1301, USA.
 //
 //////////////////////////////////////////////////////////////////////////////
 
@@ -32,6 +32,7 @@
 #include <qlistview.h>
 
 class KExifIfd;
+class KExifEntry;
 class KExifListViewItem;
 
 class KExifListView : public QListView
@@ -44,6 +45,7 @@ public:
     ~KExifListView();
 
     void    setIfdList(const QPtrList<KExifIfd>& ifdList);
+    void    setEntryList(const QPtrList<KExifEntry>& entryList);
     QString getCurrentItemName() const;
     void    setCurrentItem(const QString& itemName);
 
