@@ -18,11 +18,13 @@
 //
 //    You should have received a copy of the GNU General Public License
 //    along with this program; if not, write to the Free Software
-//    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+//    Foundation, Inc., 51 Franklin Steet, Fifth Floor, Cambridge, MA 02110-1301, USA.
 //
 //////////////////////////////////////////////////////////////////////////////
 
 #include <qpalette.h>
+#include <qfont.h>
+#include <qpainter.h>
 
 #include "kexifentry.h"
 #include "kexiflistviewitem.h"
@@ -35,7 +37,7 @@ KExifListViewItem::KExifListViewItem(QListView* parent,
 {
     if (m_exifEntry)
     {
-        setText(0, m_exifEntry->getName());
+        setText(0, m_exifEntry->getTitle());
         setText(1, m_exifEntry->getValue());
     }
 }
@@ -65,5 +67,18 @@ void KExifListViewItem::paintCell(QPainter* p, const QColorGroup& cg,
     QColorGroup cgMod(cg);
     cgMod.setColor(QColorGroup::Base, m_color);
 
+    if (column == 0)
+    {
+        p->save();
+        QFont fn(p->font());
+        fn.setBold(true);
+        p->setFont(fn);
+    }
+    
     QListViewItem::paintCell(p, cgMod, column, width, align);
+
+    if (column == 0)
+    {
+        p->restore();
+    }
 }
